<?php
/**
 * Defines various theme specific functions,
 * Implements WordPress standard hooks
 * Enables various WordPress functionalities.
 *
 * @package Mimbolove
 * @since Mimbolove 1.0.2
 */
if ( ! isset( $content_width ) ) 
		$content_width = 775; 

		add_action( 'after_setup_theme', 'mimbolove_setup' );

if ( ! function_exists( 'mimbolove_setup' ) ) {
	function mimbolove_setup() {
		add_editor_style();
		add_theme_support( 'automatic-feed-links' );	
		
		add_theme_support( 'custom-background', array(
		// Let WordPress know what our default background color is.
		// This is dependent on our current color scheme.
		'default-color' => 'white',
		) );
	
		// Add support for a variety of post formats
		add_theme_support( 'post-formats', array( 'audio', 'video', 'link', 'gallery', 'quote', 'image' ) ) ;	
	}	
}

add_action( 'init', 'mimbolove_register_nav_menus' );

function mimbolove_register_nav_menus() {		
	register_nav_menu( 
		'header-menu', __( 'Header Menu', 'Mimbolove' ) 
	);
}	

if ( function_exists( 'add_theme_support' ) ){
	add_theme_support( 'post-thumbnails' );
}

function mimbolove_javascripts_with_jquery()
{
	// Register the script like this for a theme:
	wp_register_script( 'Mimbolove', get_template_directory_uri() . '/js/mimbolove.js', array( 'jquery' ),'','yes' );

	// For either a plugin or a theme, you can then enqueue the script:
	wp_enqueue_script( 'Mimbolove' );
}
add_action( 'wp_enqueue_scripts', 'mimbolove_javascripts_with_jquery' );

if ( ! function_exists( 'mimbolove_get_post_comments' ) ) :
function mimbolove_get_post_comments() {
		if ( comments_open() && ! post_password_required() ) :
			echo '<p class="comments-link">';			
				comments_popup_link( _x( '<span class="meta-type"> 0 </span>', 'Mimbolove' ) , _x( '<span class="meta-type"> 1 </span>', 'comments number', 'Mimbolove' ), _x( '<span class="meta-type"> % </span>', 'comments number', 'Mimbolove' ) );
			echo '</p>';			
		endif;
}
endif;

if ( ! function_exists( 'mimbolove_get_post_categories' ) ) :
function mimbolove_get_post_categories() {
	$mimbolove_categories_list = get_the_category_list(', ', '');
	
	if ( $mimbolove_categories_list ):	
		printf( __( '<p title="Published under">Published under: <span class="meta-type"></span>%1$s</p>', 'Mimbolove' ), $mimbolove_categories_list );
	else:
		return false;
	endif;	
}
endif;
	
if ( ! function_exists( 'mimbolove_get_post_tags' ) ) :
function mimbolove_get_post_tags() {
	$mimbolove_tags_list = get_the_tag_list('', ', ', '');
	
	if ( $mimbolove_tags_list ):			
		printf( __( '<p title="Tagged with">Tagged with: <span class="meta-type"></span> %2$s</p>', 'Mimbolove' ), 'Mimbolove', $mimbolove_tags_list );
	else:
		return false;
	endif;	
}
endif;

if ( ! function_exists( 'mimbolove_posted_at_with_author' ) ) :

function mimbolove_posted_at_with_author() {

	printf( __( '<span class="post-date-time">Posted on <a href="%1$s" title="%2$s" rel="bookmark"><span class="entry-date" >%4$s</span></a></span><span class="post-by">Written by <a href="%5$s" title="%6$s">%7$s</a></span>', 'Mimbolove' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'M j, Y' ) ),
		esc_html( get_the_date('M j, Y') ),
		esc_html( get_author_posts_url(get_the_author_meta( 'ID' )) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'Mimbolove' ), get_the_author() ) ),
		esc_html( get_the_author() )
	);
	
}
endif;

if ( ! function_exists( 'mimbolove_get_edit_link' ) ) :
function mimbolove_get_edit_link() {
	edit_post_link( __( 'Edit', 'Mimbolove' ), '<span class="edit-link">', '</span>' );
}
endif;


if ( ! function_exists( 'mimbolove_comment' ) ) :
function mimbolove_comment( $comment, $args, $depth ) {
	
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'Mimbolove' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'Mimbolove' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>" class="comment">
			<footer class="comment-meta">
				<div class="comment-author vcard">
					<?php
						$avatar_size = 48;
						if ( '0' != $comment->comment_parent )
							$avatar_size = 39;

						echo get_avatar( $comment, $avatar_size );

						/* translators: 1: comment author, 2: date and time */
						printf( __( '%1$s on %2$s <span class="says">said:</span>', 'Mimbolove' ),
							sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
							sprintf( '<a href="%1$s"><span>%3$s</span></a>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* translators: 1: date, 2: time */
								sprintf( __( '%1$s at %2$s', 'Mimbolove' ), get_comment_date(), get_comment_time() )
							)
						);
					edit_comment_link( __( 'Edit', 'Mimbolove' ), '<span class="edit-link">', '</span>' ); ?>
				</div><!-- .comment-author .vcard -->

				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'Mimbolove' ); ?></em>
					<br />
				<?php endif; ?>

			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply <span>&darr;</span>', 'Mimbolove' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</div><!-- #comment-## -->

	<?php
			break;
	endswitch;
}
endif; // ends check for mimbolove_comment()

if ( ! function_exists( 'mimbolove_post_navigation' ) ) :
/**
 * Display navigation to next/previous pages when applicable
 */
function mimbolove_post_navigation( $nav_id ) {
	global $wp_query;

	if ( $wp_query->max_num_pages > 1 ) : ?>
		<div id="<?php echo $nav_id; ?>" class="group">
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'Mimbolove' ) ); ?></div>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'Mimbolove' ) ); ?></div>
		</div><!-- $nav_id-->
	<?php endif;
}
endif; // mimbolove_post_navigation

global $wp_version;

function mimbolove_next_prev_post_titles( $nav_id ) {
?>
<div id="<?php echo $nav_id; ?>" class="group">
	<div class="nav-previous"> <?php previous_post_link( __( '<span class="meta-nav">&larr;</span> %link', 'Mimbolove' ) );?></div>
	<div class="nav-next"> <?php next_post_link( __( '<span class="meta-nav"></span>  %link &rarr;', 'Mimbolove' ) ); ?></div>
</div><!-- $nav_id-->
<?php
} # Close of mimbolove_next_prev_post_titles

function mimbolove_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Main Sidebar', 'Mimbolove' ),
		'id' => 'sidebar-1',
		'description' => __( 'Optional: Appears on the right side of the page', 'Mimbolove' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => "</div>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	));	
	
	register_sidebar( array(
		'name' => __( 'Footer Sidebar', 'Mimbolove' ),
		'description' => __( 'Optional: Appears on the footer area of the web page', 'Mimbolove' ),
		'id' => 'sidebar-2',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => "</div>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	));
	
	
	register_sidebar( array(
		'name' => __( 'Footer Text Widget Area', 'Mimbolove' ),
		'description' => __( 'Optional: Use only the text-widget - appears inside the footer area, this is the first widget displayed even though the other footer widget area is used.', 'Mimbolove' ),
		'id' => 'sidebar-3',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => "</div>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	));	
}

add_action( 'widgets_init', 'mimbolove_widgets_init' );

// Add support for custom headers.

register_default_headers( array(
		
		'hexagons' => array(
			'url' => '%s/images/hexagons.png',
			'thumbnail_url' => '%s/images/hexagons.png',
			/* translators: header image description */
			'description' => __( 'Hexagons!', 'Mimbolove' )
		))
	);
	
	$custom_header_support = array(
		// The default header text color.
		'default-text-color' => '000',
		// The height and width of our custom header.
		'width' => '956',
		'height' => '244',
		// Random image rotation by default.
		'random-default' => true		
	);


	global $wp_version;
	if ( version_compare( $wp_version, '3.4', '>=' ) ) :
		add_theme_support( 'custom-header' );
		add_theme_support( 'custom-header', $custom_header_support );
	endif;

function mimbolove_new_excerpt_more($more) {
	global $post;
	return ' <a href="'. esc_url( get_permalink() ) . '">' . __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'twentyeleven' ) . '</a>';
}
add_filter('excerpt_more', 'mimbolove_new_excerpt_more');

function mimbolove_get_featured_image() {
	global $post;
	if ( has_post_thumbnail( $post->ID ) ) {
		echo get_the_post_thumbnail( $post->ID, 'medium' );
	}
}